@@ -6,10 +6,18 @@
 
 '''A simple Twitter client made with pyqt4'''
 
+#TODOS :
+#* Fix Identi.ca oauth bug
+#* Discover why notification some time show more new tweets than there is
+#* Implements Twitpic
+#* Push 0.1.x line to extras
+#* Refactoring, Clean and Comment the code
+#* Add retry on network errors
+
 from utils import *
 from notifications import KhweeteurNotification
 
-__version__ = '0.1.3'
+__version__ = '0.1.5'
 
 class KhweeteurActionWorker(QThread):
 
@@ -18,7 +26,6 @@ class KhweeteurActionWorker(QThread):
     info = pyqtSignal(unicode)
     warn = pyqtSignal(unicode)
     tweetSent = pyqtSignal()
-#    finished = pyqtSignal()
         
     def __init__(
         self,
@@ -78,7 +85,7 @@ class KhweeteurActionWorker(QThread):
 
             if 'twitter' in self.tb_text_replysource \
                 or self.tb_text_replyid == 0:
-                if self.settings.value('twitter_access_token_key') \
+                if bool(int(self.settings.value('twitter_access_token'))) \
                     != None:
                     api = \
                         twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,
@@ -101,7 +108,7 @@ class KhweeteurActionWorker(QThread):
 
             if 'http://identi.ca/api/' == self.tb_text_replysource \
                 or self.tb_text_replyid == 0:
-                if self.settings.value('identica_access_token_key') \
+                if bool(int(self.settings.value('identica_access_token'))) \
                     != None:
                     api = twitter.Api(base_url='http://identi.ca/api/',
                             username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
@@ -147,7 +154,7 @@ class KhweeteurCacheCleaner(QThread):
         if self.keyword:
             for filepath in glob.glob(os.path.join(CACHE_PATH,
                     os.path.normcase(unicode(self.keyword.replace('/',
-                    '_'))).encode('UTF-8')) + '/*'):  # FIXME
+                    '_'))).encode('UTF-8')) + '/*'):
                 filecdate = \
                     datetime.datetime.fromtimestamp(os.path.getctime(filepath))
                 if (now - filecdate).days > 45:
@@ -179,7 +186,7 @@ class KhweeteurRefreshWorker(QThread):
         self.api = api
         self.settings = QSettings()
 
-    def run(self):
+    def run(self):        
         pass
 
     def getCacheFolder(self):
@@ -295,7 +302,7 @@ class KhweeteurHomeTimelineWorker(KhweeteurRefreshWorker):
     def run(self):
 
         # Get Home TimeLine
-
+        print 'Refresh KhweeteurHomeTimelineWorker'
         try:
             statuses = \
                 self.api.GetFriendsTimeline(since_id=self.settings.value('last_id/'
@@ -309,6 +316,8 @@ class KhweeteurHomeTimelineWorker(KhweeteurRefreshWorker):
             statuses.sort()
             statuses.reverse()
             if len(statuses) > 0:
+                print 'Got new status', [status.id for status in
+                        statuses]
                 self.newStatuses.emit([status.id for status in
                         statuses])
                 self.settings.setValue('last_id/' + self.api.base_url
@@ -689,7 +698,7 @@ class KhweeteurWorker(QThread):
         threads = []
 
         try:
-            if self.settings.value('twitter_access_token_key') != None:
+            if bool(int(self.settings.value('twitter_access_token'))):
 
                 # Login to twitter
 
@@ -714,7 +723,7 @@ class KhweeteurWorker(QThread):
 
         try:
             identica_mlist = []
-            if self.settings.value('identica_access_token_key') != None:
+            if bool(int(self.settings.value('identica_access_token'))):
                 if not hasattr(self, 'identica_api'):
                     self.identica_api = \
                         twitter.Api(base_url='http://identi.ca/api/',
@@ -743,8 +752,11 @@ class KhweeteurWorker(QThread):
                 print 'Error during twitter refresh : ', \
                     self.error.message
                 self.info.emit(self.error.message)  # fix bug#404
+            elif type(self.error) == urllib2.httplib.BadStatusLine:
+                print 'Bad status line : ', self.error.line
             else:
                 self.info.emit('A network error occur')
+        print 'DEBUG:Refresh ended'
 
 
 class KhweetsModel(QAbstractListModel):
@@ -770,6 +782,13 @@ class KhweetsModel(QAbstractListModel):
     def setLimit(self, limit):
         self.khweets_limit = limit
 
+
+    def orderLimitAndCacheUids(self):
+        self._items.sort()
+        self._items.reverse()
+        self._items = self._items[:self.khweets_limit]
+        self._uids = [item[1] for item in self._items]
+
     def GetRelativeCreatedAt(self, timestamp):
         '''Get a human redable string representing the posting time
 
@@ -828,10 +847,6 @@ class KhweetsModel(QAbstractListModel):
             except StandardError, e:
                 print e
 
-#        QObject.emit(self,
-#                     SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
-#                     ), self.createIndex(0, 0), self.createIndex(0,
-#                     len(self._uids)))
         self.dataChanged.emit(self.createIndex(0, 0),
                               self.createIndex(0,
                               len(self._items)))
@@ -858,29 +873,22 @@ class KhweetsModel(QAbstractListModel):
             traceback.print_exc()
 
         if len(keys) > 0:
-            self._items.sort()
-            self._items.reverse()
-            self._items = self._items[:self.khweets_limit]
-            self._new_counter += len(keys)
+            self.orderLimitAndCacheUids()
+
+            for key in keys:
+                if key in self._uids:
+                    self._new_counter += 1
 
-#            QObject.emit(self,
-#                         SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
-#                         ), self.createIndex(0, 0), self.createIndex(0,
-#                         len(self._items)))
             self.dataChanged.emit(self.createIndex(0, 0),
                                   self.createIndex(0,
                                   len(self._items)))
-            # self.serialize()
 
     def destroyStatus(self, index):
         self._items.pop(index.row())
-#        QObject.emit(self,
-#                     SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
-#                     ), self.createIndex(0, 0), self.createIndex(0,
-#                     len(self._items)))
         self.dataChanged.emit(self.createIndex(0, 0),
                               self.createIndex(0,
                               len(self._items)))
+                              
     def getNewAndReset(self):
         counter = self._new_counter
         self._new_counter = 0
@@ -991,7 +999,10 @@ class KhweetsModel(QAbstractListModel):
                         unicode(self.keyword.replace('/', '_')))))
                 uids = glob.glob(cach_path + u'/*')
 
-            if len(uids) == 0:
+            if len(uids) != 0:
+                self._createCacheList(cach_path, uids)
+
+            if len(self._uids) == 0:
                 print 'Cache cleared'
                 self.settings = QSettings()
                 if not self.keyword:
@@ -999,18 +1010,14 @@ class KhweetsModel(QAbstractListModel):
                 else:
                     self.settings.remove(self.keyword + '/last_id')
             else:
-                self._createCacheList(cach_path, uids)
-                self._items.sort()
-                self._items.reverse()
+                self.orderLimitAndCacheUids()
+
         except StandardError, e:
             print 'unSerialize : ', e
-#            QObject.emit(self,
-#                         SIGNAL('dataChanged(const QModelIndex&, const QModelIndex &)'
-#                         ), self.createIndex(0, 0), self.createIndex(0,
-#                         len(self._items)))
             self.dataChanged.emit(self.createIndex(0, 0),
                                   self.createIndex(0,
                                   len(self._items)))
+
     def data(self, index, role=Qt.DisplayRole):
 
         # 0 -> Created_at,
@@ -1105,8 +1112,8 @@ class DefaultCustomDelegate(QStyledItemDelegate):
     def sizeHint(self, option, index):
         '''Custom size calculation of our items'''
 
-        uid = str(index.data(role=IDROLE)) + 'x' \
-            + str(option.rect.width())
+	uid = str(index.data(role=IDROLE)) + 'x' + \
+		str(option.rect.width())
         try:
             return self.memoized_size[uid]
         except:
@@ -1540,6 +1547,17 @@ class KhweeteurWin(QMainWindow):
 
         self.settings = QSettings()
 
+        #Crappy fix for old prefs due to change to QVariant
+        #Api 2 and PySide
+        if self.settings.value('twitter_access_token') in ('True','1'):
+            self.settings.setValue('twitter_access_token',1)
+        else:
+            self.settings.setValue('twitter_access_token',0)
+        if self.settings.value('identica_access_token') in ('True','1'):
+            self.settings.setValue('identica_access_token',1)
+        else:
+            self.settings.setValue('identica_access_token',0)
+        
         try:
             if int(self.settings.value('useGPS')) == 2:
                 if self.parent != None:
@@ -1600,13 +1618,13 @@ class KhweeteurWin(QMainWindow):
 
     def justAfterInit(self):
 
+        self.notifications = KhweeteurNotification()
+
         if not noDBUS:
             from nwmanager import NetworkManager
             self.nw = NetworkManager(self.refresh_timeline)
         else:
-            self.refresh_timeline
-
-        self.notifications = KhweeteurNotification()
+            self.refresh_timeline()
 
         self.connect(self.timer, SIGNAL('timeout()'),
                      self.timed_refresh)
@@ -2159,8 +2177,8 @@ class KhweeteurWin(QMainWindow):
             self.tweetAction.finished.connect(self.tweetSentFinished)
             self.tweetAction.info.connect(self.notifications.info)
             self.tweetAction.warn.connect(self.notifications.warn)
-            self.tweetAction.tweetSent.connect(self.tweetSentFinished)
-            self.tweetAction.finished.connect(self.tweetSent)
+            self.tweetAction.tweetSent.connect(self.tweetSent)
+            self.tweetAction.finished.connect(self.tweetSentFinished)
             self.tweetAction.start()
 
     def refreshEnded(self):
@@ -2179,7 +2197,7 @@ class KhweeteurWin(QMainWindow):
         if self.search_keyword == 'GeOSearH':
             if self.parent.coordinates:
                 geocode = (self.parent.coordinates[0],
-                           self.parent.coordinates[1], '1km')  # FIXME
+                           self.parent.coordinates[1], '1km')
             else:
                 geocode = None
         else:
@@ -2280,36 +2298,35 @@ class KhweeteurWin(QMainWindow):
 
         fileMenu.addAction(self.tr('&About'), self.do_about)
 
-    def twitpic_upload(self):
-        message = 'Test'
-        import twitpic2
-        api = \
-            twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,
-                password=KHWEETEUR_TWITTER_CONSUMER_SECRET,
-                access_token_key=str(self.settings.value('twitter_access_token_key'
-                )),
-                access_token_secret=str(self.settings.value('twitter_access_token_secret'
-                )))
-        twitpic = twitpic2.TwitPicOAuthClient(
-            consumer_key = KHWEETEUR_TWITTER_CONSUMER_KEY,
-            consumer_secret = KHWEETEUR_TWITTER_CONSUMER_SECRET,
-            access_token = ACCESS_TOKEN, #FIXME
-            service_key = 'f9b7357e0dc5473df5f141145e4dceb0'
-            )
-        # methods - read, create, update, remove
-        params = []
-        params['media'] = 'khweeteur.png'
-        params['message'] = 'Test of python-twitpic module from #Khweeteur'
-        response = twitpic2.create('upload', params)
-        print response
+#    def twitpic_upload(self):
+#        message = 'Test'
+#        import twitpic2
+#        api = \
+#            twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,
+#                password=KHWEETEUR_TWITTER_CONSUMER_SECRET,
+#                access_token_key=str(self.settings.value('twitter_access_token_key'
+#                )),
+#                access_token_secret=str(self.settings.value('twitter_access_token_secret'
+#                )))
+#        twitpic = twitpic2.TwitPicOAuthClient(
+#            consumer_key = KHWEETEUR_TWITTER_CONSUMER_KEY,
+#            consumer_secret = KHWEETEUR_TWITTER_CONSUMER_SECRET,
+#            access_token = ACCESS_TOKEN, #FIXME
+#            service_key = 'f9b7357e0dc5473df5f141145e4dceb0'
+#            )
+#        # methods - read, create, update, remove
+#        params = []
+#        params['media'] = 'khweeteur.png'
+#        params['message'] = 'Test of python-twitpic module from #Khweeteur'
+#        response = twitpic2.create('upload', params)
+#        print response
         
     def del_search(self):
         keywords = self.settings.value('savedSearch')
         if not keywords:
+            keywords = []            
+        elif type(keywords) == unicode:
             keywords = []
-        elif type(keywords) == str:
-            if self.search_keyword == keywords:
-                keywords = []
         elif type(keywords) == list:
             try:
                 keywords.remove(self.search_keyword)
@@ -2324,19 +2341,23 @@ class KhweeteurWin(QMainWindow):
         keywords = self.settings.value('savedSearch')
         if not keywords:
             keywords = []
-        elif type(keywords) == str:
-            keywords = [keywords]
+        elif type(keywords) == unicode:
+            keywords = [keywords,]
         keywords.append(self.search_keyword)
         self.settings.setValue('savedSearch', keywords)
 
     def open_saved_search(self):
         keywords = self.settings.value('savedSearch')
-        if type(keywords) == str:
-            keywords = [keywords]
+        if type(keywords) == unicode:
+            keywords = [keywords,]
 
         if keywords != None:
-            for keyword in keywords:
-                self.do_search(keyword)
+            if type(keywords)==list:
+                for keyword in keywords:
+                    self.do_search(keyword)
+            else:
+                self.settings.setValue('savedSearch',[])
+                
         self.activateWindow()
 
     def open_search(self):
