@@ -17,6 +17,47 @@ KHWEETEUR_STATUSNET_CONSUMER_SECRET = 'fbc51241e2ab12e526f89c26c6ca5837'
 import oauth2 as oauth
 from notifications import KhweeteurNotification
 
+from PySide.QtWebKit import *
+
+
+javaScriptLogin = """ 
+return document.getElementsByName('oauth_pin'); 
+ """  
+   
+class OAuthWeb(QWebView):  
+    def __init__(self, parent=None):  
+        QWebView.__init__(self,parent)  
+        self.loggedIn = False  
+   
+    def open(self, url):  
+        """."""  
+        self.url = QUrl(url)  
+        self.loadFinished.connect(self._loadFinished)  
+        self.load(self.url)
+        self.show()
+   
+    def createWindow(self, windowType):  
+        """Load links in the same web-view."""  
+        return self  
+   
+    def _loadFinished(self):  
+#        if self.loggedIn:  
+#            self.loadFinished.disconnect(self._loadFinished)  
+   
+#        self.loggedIn = True  
+        print self.page().mainFrame().evaluateJavaScript(javaScriptLogin)  
+   
+#    def contextMenuEvent(self, event):  
+#        """Add a 'Back to GMail' entry."""  
+#        menu = self.page().createStandardContextMenu()  
+#        menu.addSeparator()  
+#        action = menu.addAction('Back to GMail')  
+#        @action.triggered.connect  
+#        def backToGMail():  
+#            self.load(self.url)  
+#        menu.exec_(QtGui.QCursor.pos())  
+
+
 class KhweeteurPref(QMainWindow):
 
     save = pyqtSignal()
@@ -107,10 +148,10 @@ class KhweeteurPref(QMainWindow):
 
     def request_twitter_access_or_clear(self):
         ''' Request or clear twitter auth token'''
-        if self.settings.value('twitter_access_token'):
+        if bool(self.settings.value('twitter_access_token')):
             self.settings.setValue('twitter_access_token_key','')
             self.settings.setValue('twitter_access_token_secret','')
-            self.settings.setValue('twitter_access_token',False)
+            self.settings.setValue('twitter_access_token',0)
             self.twitter_value.setText(self.tr('Auth on Twitter'))
         else:
 
@@ -166,13 +207,13 @@ class KhweeteurPref(QMainWindow):
                             KhweeteurNotification().warn(self.tr('The request for a Token did not succeed: %s') % resp['status'])
                             self.settings.setValue('twitter_access_token_key','')
                             self.settings.setValue('twitter_access_token_secret','')
-                            self.settings.setValue('twitter_access_token',False)
+                            self.settings.setValue('twitter_access_token',0)
                         else:
                             #print access_token['oauth_token']
                             #print access_token['oauth_token_secret']
                             self.settings.setValue('twitter_access_token_key',access_token['oauth_token'])
                             self.settings.setValue('twitter_access_token_secret',access_token['oauth_token_secret'])
-                            self.settings.setValue('twitter_access_token',True)
+                            self.settings.setValue('twitter_access_token',1)
                             self.twitter_value.setText(self.tr('Clear Twitter Auth'))
                             KhweeteurNotification().info(self.tr('Khweeteur is now authorized to connect'))
                         if isMAEMO:
@@ -181,10 +222,10 @@ class KhweeteurPref(QMainWindow):
     def request_identica_access_or_clear(self):
         ''' Request or clear identi.ca auth token'''
         import urllib
-        if self.settings.value('identica_access_token'):
+        if bool(self.settings.value('identica_access_token')):
             self.settings.setValue('identica_access_token_key','')
             self.settings.setValue('identica_access_token_secret','')
-            self.settings.setValue('identica_access_token',False)
+            self.settings.setValue('identica_access_token',0)
             self.identica_value.setText(self.tr('Auth on Identi.ca'))
         else:
             try:
@@ -229,8 +270,13 @@ class KhweeteurPref(QMainWindow):
 
                     QDesktopServices.openUrl(QUrl('%s?oauth_token=%s' % (AUTHORIZATION_URL, request_token['oauth_token'])))
 
-                    pincode, ok = QInputDialog.getText(self, self.tr('Identi.ca Authentification'), self.tr('Enter the token :'))
+#                    Javascript didn t work yet
+#                    self.wbkt=OAuthWeb()
+#                    self.wbkt.open(('%s?oauth_token=%s' % (AUTHORIZATION_URL, request_token['oauth_token'])))
 
+
+                    pincode, ok = QInputDialog.getText(self, self.tr('Identi.ca Authentification'), self.tr('Enter the token :'))
+#                    ok = False
                     if ok:
                         if isMAEMO:
                             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
@@ -249,13 +295,13 @@ class KhweeteurPref(QMainWindow):
                             KhweeteurNotification().warn(self.tr('The request for a Token did not succeed: %s') % resp['status'])
                             self.settings.setValue('identica_access_token_key','')
                             self.settings.setValue('identica_access_token_secret','')
-                            self.settings.setValue('identica_access_token',False)
+                            self.settings.setValue('identica_access_token',0)
                         else:
                             #print access_token['oauth_token']
                             #print access_token['oauth_token_secret']
                             self.settings.setValue('identica_access_token_key',access_token['oauth_token'])
                             self.settings.setValue('identica_access_token_secret',access_token['oauth_token_secret'])
-                            self.settings.setValue('identica_access_token',True)
+                            self.settings.setValue('identica_access_token',1)
                             self.identica_value.setText(self.tr('Clear Identi.ca Auth'))
                             KhweeteurNotification().info(self.tr('Khweeteur is now authorized to connect'))
                         if isMAEMO:
@@ -321,13 +367,13 @@ class KhweeteurPref(QMainWindow):
                             KhweeteurNotification().warn(self.tr('The request for a Token did not succeed: %s') % resp['status'])
                             self.settings.setValue('statusnet_access_token_key','')
                             self.settings.setValue('statusnet_access_token_secret','')
-                            self.settings.setValue('statusnet_access_token',False)
+                            self.settings.setValue('statusnet_access_token',0)
                         else:
                             #print access_token['oauth_token']
                             #print access_token['oauth_token_secret']
                             self.settings.setValue('statusnet_access_token_key',access_token['oauth_token'])
                             self.settings.setValue('statusnet_access_token_secret',access_token['oauth_token_secret'])
-                            self.settings.setValue('statusnet_access_token',True)
+                            self.settings.setValue('statusnet_access_token',1)
                             self.statusnet_value.setText(self.tr('Clear Status.net Auth'))
                             KhweeteurNotification().info(self.tr('Khweeteur is now authorized to connect'))
                         if isMAEMO:
@@ -351,16 +397,21 @@ class KhweeteurPref(QMainWindow):
         self._main_layout = QGridLayout(self.aWidget)
 
         self._main_layout.addWidget(QLabel(self.tr('Authorizations :')),0,0)
-        if self.settings.value(self.tr('twitter_access_token')):
-            self.twitter_value = QPushButton(self.tr('Clear Twitter Auth'))
-        else:
+        try:
+            if bool(int(self.settings.value(self.tr('twitter_access_token')))):
+                self.twitter_value = QPushButton(self.tr('Clear Twitter Auth'))
+            else:
+                self.twitter_value = QPushButton(self.tr('Auth on Twitter'))
+        except:
             self.twitter_value = QPushButton(self.tr('Auth on Twitter'))
         self._main_layout.addWidget(self.twitter_value,0,1)
         self.connect(self.twitter_value, SIGNAL('clicked()'), self.request_twitter_access_or_clear)
-
-        if self.settings.value('identica_access_token'):
-            self.identica_value = QPushButton(self.tr('Clear Identi.ca Auth'))
-        else:
+        try:
+            if bool(int(self.settings.value('identica_access_token'))):
+                self.identica_value = QPushButton(self.tr('Clear Identi.ca Auth'))
+            else:
+                self.identica_value = QPushButton(self.tr('Auth on Identi.ca'))
+        except:
             self.identica_value = QPushButton(self.tr('Auth on Identi.ca'))
         self._main_layout.addWidget(self.identica_value,1,1)
         self.connect(self.identica_value, SIGNAL('clicked()'), self.request_identica_access_or_clear)
@@ -372,7 +423,7 @@ class KhweeteurPref(QMainWindow):
         self.refresh_value = QSpinBox()
         self._main_layout.addWidget(self.refresh_value,3,1)
 
-        self._main_layout.addWidget(QLabel(self.tr('Number of tweet to keep in the view (History) :')),4,0)
+        self._main_layout.addWidget(QLabel(self.tr('Number of tweet to keep in the view :')),4,0)
         self.history_value = QSpinBox()
         self._main_layout.addWidget(self.history_value,4,1)
 
